<?php
/*
* The Strangecode Codebase - a general application development framework for PHP
* For details visit the project site: <http://trac.strangecode.com/>
* Copyright © 2015 Strangecode, LLC
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*
* Small config file for cli scripts in the codebase/bin directory.
*
* @author   Quinn Comendant <quinn@strangecode.com>
* @version  1.0
* @since    12 Jul 2015 22:48:13
*/

$this_script = basename($_SERVER['argv'][0]);

// Assume execution occurs while in the common app directory.
define('COMMON_BASE', realpath('.'));
$db_auth_file = false;
$rii = new RecursiveIteratorIterator(new RecursiveDirectoryIterator(COMMON_BASE));
$rii->setMaxDepth(2);
foreach ($rii as $filename => $file) {
    if (in_array(basename($filename), ['db_auth.inc.php', 'db_auth.json'])) {
        $db_auth_file = $filename;
        break;
    }
}
if (!$db_auth_file) {
    die(sprintf("%s error: the current directory must be common site directory (i.e. the parent directory of the document root) AND a db_auth file must exist within two directory levels.\n", $this_script));
}
if (fileowner($db_auth_file) != getmyuid()) {
    die(sprintf("%s error: you must execute this script as the owner of the web files.\n", $this_script));
}

// Set include path.
ini_set('include_path', get_include_path() . PATH_SEPARATOR . COMMON_BASE);

/********************************************************************
* CONFIG
********************************************************************/

// Include core libraries.
require_once 'codebase/lib/App.inc.php';
require_once 'codebase/lib/Utilities.inc.php';

define('_CLI', true);
$app =& App::getInstance('codebase');
$app->setParam(array(
    'site_name' => 'codebase',
    'site_email' => 'codebase@strangecode.com',
    'enable_session' => false,
    'enable_db' => true,
    'db_create_tables' => true,
    'db_auth_file' => $db_auth_file,
    'db_always_debug' => false,
    'db_debug' => true,
    'db_die_on_failure' => true,
    'display_errors' => true,
    'error_reporting' => E_ALL,
    'log_file_priority' => false,
    'log_screen_priority' => LOG_INFO,
    'log_directory' => COMMON_BASE . '/log',
    'log_filename' => 'site_log',
));

if (strtolower(getFilenameExtension($db_auth_file)) != 'json') {
    // DB auth file is not json, and will not be automaticlaly be loaded by $app's 'db_auth_file' parser.
    require_once $db_auth_file;
}

// Start application-based functionality: database, session, environment, ini setup, etc.
// Most configuration parameters must be set before starting the App.
$app->start();

// Global DB object. Automatically pre-configured by $app->start().
$db =& DB::getInstance();
